from tests.BaseRunner import BaseRunner


class TestGCC(BaseRunner):

    def setUp(self):
        self.expected_venue = "GCC"

        self.correct_strings = {
            "GCC",  # used by DBLP
            "GCC (1)",  # DBLP
            "Grid and Cooperative Computing, Second International Workshop, {GCC} 2003, Shanghai, China, December 7-10, 2003, Revised Papers, Part {II}",
            "International Conference on Grid and Cooperative Computing",
            "{GCC} 2010, The Ninth International Conference on Grid and Cloud Computing, Nanjing, Jiangsu, China, 1-5 November 2010",
            "Grid and Cooperative Computing, Second International Workshop, {GCC} 2003, Shanghai, China, December 7-10, 2003, Revised Papers, Part {II}",
            }

        self.wrong_strings = {
            "Grid and Cooperative Computing - {GCC} 2004 Workshops: {GCC} 2004 International Workshops, IGKG, SGT, GISS, AAC-GEVO, and VVS, Wuhan, China, October 21-24, 2004. Proceedings",
        }



from tests.BaseRunner import BaseRunner


class TestISCID(BaseRunner):

    def setUp(self):
        self.expected_venue = "ISCID"

        self.correct_strings = {
            "ISCID",  # used by DBLP
            "ISCID (1)",  # DBLP
            "ISCID (2)",  # DBLP
            "2009 Second International Symposium on Computational Intelligence and Design, {ISCID} 2009, Changsha, Hunan, China, 12-14 December 2009, 2 Volumes",
            "Computational Intelligence and Design, 2009. ISCID'09. Second International Symposium on",
            "2011 Fourth International Symposium on Computational Intelligence and Design",
        }

        self.wrong_strings = {
        }



from tests.BaseRunner import BaseRunner


class TestSoCC(BaseRunner):

    def setUp(self):
        self.expected_venue = "SoCC"

        self.correct_strings = {
            "SoCC",  # used by DBLP
            "Proceedings of the 1st {ACM} Symposium on Cloud Computing, SoCC 2010, Indianapolis, Indiana, USA, June 10-11, 2010",
            "Proceedings of the 1st ACM symposium on Cloud computing",
            "Proceedings of the {ACM} Symposium on Cloud Computing, SoCC 2018, Carlsbad, CA, USA, October 11-13, 2018",
        }

        self.wrong_strings = {
            }



from tests.BaseRunner import BaseRunner


class TestIJHPCA(BaseRunner):

    def setUp(self):
        self.expected_venue = "IJHPCA"

        self.correct_strings = {
            "IJHPCA",  # used by DBLP
            "IJHPCA (1)",  # DBLP
            "{IJHPCA}",
            "The International Journal of High Performance Computing Applications",  # Google Scholar
        }

        self.wrong_strings = {
        }



from tests.BaseRunner import BaseRunner


class TestICAC(BaseRunner):

    def setUp(self):
        self.expected_venue = "ICAC"

        self.correct_strings = {
            "ICAC",
            "1st International Conference on Autonomic Computing {(ICAC} 2004), 17-19 May 2004, New York, NY, {USA}",
            "International Conference on Autonomic Computing, 2004. Proceedings.",
            "2018 {IEEE} International Conference on Autonomic Computing, {ICAC} 2018, Trento, Italy, September 3-7, 2018",
        }

        self.wrong_strings = {
        }



from tests.BaseRunner import BaseRunner


class TestTPDS(BaseRunner):

    def setUp(self):
        self.expected_venue = "TPDS"

        self.correct_strings = {
            "IEEE Trans. Parallel Distrib. Syst.",  # used by DBLP
            "{IEEE} Trans. Parallel Distrib. Syst.",
            "IEEE Transactions on parallel and distributed systems",  # Google Scholar
            "IEEE transactions on parallel and distributed systems",
        }

        self.wrong_strings = {
        }



from tests.BaseRunner import BaseRunner


class TestSIGCOMM(BaseRunner):

    def setUp(self):
        self.expected_venue = "SIGCOMM"

        self.correct_strings = {
            "SIGCOMM",  # used by DBLP
            "{SIGCOMM} '81, Proceedings of the seventh symposium on Data communications, 1981",
            "ACM SIGCOMM Computer Communication Review",  # Google Scholar
            "Proceedings of the {ACM} {SIGCOMM} conference on Communications architectures {\&} protocols, 1986, Stowe, Vermont, United States, August 5-7, 1986",
            "Proceedings of the {ACM} {SIGCOMM} 1995 Conference on Applications, Technologies, Architectures, and Protocols for Computer Communication, Cambridge, MA, USA, August 28 - September 1, 1995.",
            "Proceedings of the 2018 Conference of the {ACM} Special Interest Group on Data Communication, {SIGCOMM} 2018, Budapest, Hungary, August 20-25, 2018",
            "Proceedings of the 2018 Conference of the ACM Special Interest Group on Data Communication",
        }

        self.wrong_strings = {
            "Proceedings of the first workshop on Hot topics in software defined networks, HotSDN@SIGCOMM 2012, Helsinki, Finland, August 13, 2012",
            "Proceedings of the first edition of the {MCC} workshop on Mobile cloud computing, MCC@SIGCOMM 2012, Helsinki, Finland, August 17, 2012",
            "Proceedings of the 2013 {ACM} {SIGCOMM} workshop on Future human-centric multimedia networking, FhMN@SIGCOMM 2013, Hong Kong, China, August 16, 2013",
            "Proceedings of the 5th {ACM} workshop on Hot topics in planet-scale measurement, HotPlanet@SIGCOMM 2013, Hong Kong, China, August 12-16, 2013",
        }



from tests.BaseRunner import BaseRunner


class TestSIGCSE(BaseRunner):

    def setUp(self):
        self.expected_venue = "SIGCSE"

        self.correct_strings = {
            "SIGSCSE",  # used by DBLP
            "Proceedings of the 17st {SIGCSE} Technical Symposium on Computer Science Education, 1986, Cincinnati, Ohio, USA, February 6-7, 1986",
            "Proceedings of the 49th {ACM} Technical Symposium on Computer Science Education, {SIGCSE} 2018, Baltimore, MD, USA, February 21-24, 2018",
            "Proceedings of the 49th ACM Technical Symposium on Computer Science Education", # Google Scholar
        }

        self.wrong_strings = {
            }



from tests.BaseRunner import BaseRunner


class TestHiPC(BaseRunner):

    def setUp(self):
        self.expected_venue = "HiPC"

        self.correct_strings = {
            "HiPC",  # Used by DBLP
            "23rd {IEEE} International Conference on High Performance Computing, HiPC 2016, Hyderabad, India, December 19-22, 2016",
            "2016 IEEE 23rd International Conference on High Performance Computing (HiPC)",
            "3rd International Conference on High Performance Computing, {HIPC} 1996, Proceedings, Trivandrum, India, 19-22 December, 1996",
            "High Performance Computing - HiPC'99, 6th International Conference, Calcutta, India, December 17-20, 1999, Proceedings",
        }

        self.wrong_strings = {
        }



from tests.BaseRunner import BaseRunner


class TestNDSS(BaseRunner):

    def setUp(self):
        self.expected_venue = "NDSS"

        self.correct_strings = {
            "NDSS",  # used by DBLP
            "1995 Symposium on Network and Distributed System Security, {(S)NDSS} '95, San Diego, California, USA, February 16-17, 1995",
            "Network and Distributed System Security, 1995., Proceedings of the Symposium on",
            "5th Annual Network and Distributed System Security Symposium, {NDSS} 2018, San Diego, California, USA, February 18-21, 2018",
            "Proc. Network and Distributed Systems Symposium (NDSS)",
        }

        self.wrong_strings = {
        }



from tests.BaseRunner import BaseRunner


class TestCLUSTER(BaseRunner):

    def setUp(self):
        self.expected_venue = "CLUSTER"

        self.correct_strings = {
            "CLUSTER",  # used by DBLP
            "2000 {IEEE} International Conference on Cluster Computing {(CLUSTER} 2000), November 28th - December 1st, 2000, Technische Universit{\"{a}}t Chemnitz, Saxony, Germany",
            "Cluster Computing, 2000. Proceedings. IEEE International Conference on",
            "{IEEE} International Conference on Cluster Computing, {CLUSTER} 2018, Belfast, UK, September 10-13, 2018",
            "2016 IEEE International Conference on Cluster Computing (CLUSTER)",
            }

        self.wrong_strings = {
            }



from tests.BaseRunner import BaseRunner


class TestCloudComp(BaseRunner):

    def setUp(self):
        self.expected_venue = "CloudComp"

        self.correct_strings = {
            "CloudComp",
            "Cloud Computing - First International Conference, CloudComp 2009, Munich, Germany, October 19-21, 2009 Revised Selected Papers",
            "Cloud Computing - 6th International Conference, CloudComp 2015, Daejeon, South Korea, October 28-29, 2015, Proceedings",
            "International Conference on Cloud Computing", # Google Scholar
        }

        self.wrong_strings = {
            }



from tests.BaseRunner import BaseRunner


class TestICCSE(BaseRunner):

    def setUp(self):
        self.expected_venue = "ICCSE"

        self.correct_strings = {
            "ICCSE",
            "2016 11th International Conference on Computer Science \& Education (ICCSE)",
            "15th International Conference on Computer Science {\&} Education, {ICCSE} 2020, Delft, The Netherlands, August 18-22, 2020",
        }

        self.wrong_strings = {
        }



from tests.BaseRunner import BaseRunner


class TestICPE(BaseRunner):

    def setUp(self):
        self.expected_venue = "ICPE"

        self.correct_strings = {
            "ICPE",  # used by DBLP
            "{WOSP}",  # DBLP
            "Proceedings of the 1st international workshop on Software and performance",
            "Proceedings of the first joint {WOSP/SIPEW} International Conference on Performance Engineering, San Jose, California, USA, January 28-30, 2010",
            "ICPE'11 - Second Joint {WOSP/SIPEW} International Conference on Performance Engineering, Karlsruhe, Germany, March 14-16, 2011",
            "Proceedings of the 2018 {ACM/SPEC} International Conference on Performance Engineering, {ICPE} 2018, Berlin, Germany, April 09-13, 2018",
        }

        self.wrong_strings = {
            "Proceedings of the 2013 international workshop on Hot topics in cloud services, HotTopiCS 2013, co-located with ICPE'13, Czech Republic, April 20-21, 2013",
            "Proceedings of the 2015 Workshop on Challenges in Performance Methods for Software Development, WOSP-C'15, Austin, TX, USA, January 31, 2015",
            "Companion of the 2018 {ACM/SPEC} International Conference on Performance Engineering, {ICPE} 2018, Berlin, Germany, April 09-13, 2018",
            "Power Electronics and ECCE Asia (ICPE-ECCE Asia), 2015 9th International Conference on",
            "ICPE Companion",  # Semantic Scholar
        }



from tests.BaseRunner import BaseRunner


class TestHPCC(BaseRunner):

    def setUp(self):
        self.expected_venue = "HPCC"

        self.correct_strings = {
            "HPCC",  # used by DBLP
            "HPCC-ICESS",  # DBLP
            "HPCC/CSS/ICESS",  # DBLP
            "HPCC/SmartCity/DSS",  # DBLP
            "HPCC/EUC",  # DBLP
            "High Performance Computing and Communications, First International Conference, {HPCC} 2005, Sorrento, Italy, September 21-23, 2005, Proceedings",
            "International Conference on High Performance Computing and Communications",
            "14th {IEEE} International Conference on High Performance Computing and Communication {\&} 9th {IEEE} International Conference on Embedded Software and Systems, {HPCC-ICESS} 2012, Liverpool, United Kingdom, June 25-27, 2012",
            "High Performance Computing and Communication \& 2012 IEEE 9th International Conference on Embedded Software and Systems (HPCC-ICESS), 2012 IEEE 14th International Conference on",
            "17th {IEEE} International Conference on High Performance Computing and Communications, {HPCC} 2015, 7th {IEEE} International Symposium on Cyberspace Safety and Security, {CSS} 2015, and 12th {IEEE} International Conference on Embedded Software and Systems, {ICESS} 2015, New York, NY, USA, August 24-26, 2015",
            "10th {IEEE} International Conference on High Performance Computing and Communications, {HPCC} 2008, 25-27 Sept. 2008, Dalian, China",
        }


        self.wrong_strings = {
        }



from tests.BaseRunner import BaseRunner


class TestHPDC(BaseRunner):

    def setUp(self):
        self.expected_venue = "HPDC"

        self.correct_strings = {
            r"HPDC",  # used by DBLP
            r"Proceedings of the 27th International Symposium on High-Performance Parallel and Distributed Computing, {HPDC} 2018, Tempe, AZ, USA, June 11-15, 2018",
            r"Proceedings of the First International Symposium on High Performance Distributed Computing, HPDC '92, Syracuse, NY, USA, September 9-11, 1992",
            r"High-Performance Distributed Computing, 1992.(HPDC-1), Proceedings of the First International Symposium on",
            r"11th {IEEE} International Symposium on High Performance Distributed Computing {(HPDC-11} 2002), 23-26 July 2002, Edinburgh, Scotland, {UK}",
            r"Another: Proceedings of the 16th International Symposium on High-Performance Distributed Computing {(HPDC-16} 2007), 25-29 June 2007, Monterey, California, {USA}",
            r"12th International Symposium on High-Performance Distributed Computing {(HPDC-12} 2003), 22-24 June 2003, Seattle, WA, {USA}",
        }

        self.wrong_strings = {
            r"AI-Science@HPDC", "ScienceCloud@HPDC", "ROSS@HPDC",
            r"Proceedings of the 5th IEEE workshop on Challenges of large applications in distributed environments, CLADE@HPDC 2007, Monterey, California, USA, June 25, 2007",
            r"Proceedings of the 2nd Workshop on the Use of P2P, GRID and Agents for the Development of Content Networks, UPGRADE-CN'07, jointly held with the 16th International Symposium on High-Performance Distributed Computing (HPDC-16 2007), 26 June 2007, Monterey, California, USA."
            r"Proceedings of the 2007 workshop on Grid monitoring, GMW@HPDC 2007, Monterey, California, USA, June 25, 2007",
            r"Proceedings of the 3rd Workshop on the Use of P2P, GRID and Agents for the Development of Content Networks, UPGRADE-CN'08, jointly held with the 17th International Symposium on High-Performance Distributed Computing (HPDC-17 2008), 23 June 2008, Boston, MA, USA",
            r"Proceedings of the 7th International Workshop on Runtime and Operating Systems for Supercomputers, ROSS@HPDC 2017, Washingon, DC, DC, USA, June 27 - 27, 2017.",
            r"Proceedings of the 1st International Workshop on Autonomous Infrastructure for Science, AI-Science@HPDC 2018, Tempe, AZ, USA, June 11, 2018.",
        }



from tests.BaseRunner import BaseRunner


class TestSYSTOR(BaseRunner):

    def setUp(self):
        self.expected_venue = "SYSTOR"

        self.correct_strings = {
            r"SYSTOR",  # used by DBLP
            r"Proceedings of of {SYSTOR} 2009: The Israeli Experimental Systems Conference 2009, Haifa, Israel, May 4-6, 2009",  # DBLP
            r"International Conference on Systems and Storage, {SYSTOR} 2014, Haifa, Israel, June 30 - July 02, 2014",
            r"Proceedings of SYSTOR 2009: The Israeli Experimental Systems Conference",
            r"Proceedings of International Conference on Systems and Storage",
            r"Proceedings of the 12th {ACM} International Conference on Systems and Storage, {SYSTOR} 2019, Haifa, Israel, June 3-5, 2019",
            r"Proceedings of the 12th ACM International Conference on Systems and Storage",
        }

        self.wrong_strings = {

        }



from tests.BaseRunner import BaseRunner


class TestPPOPP(BaseRunner):

    def setUp(self):
        self.expected_venue = "PPOPP"

        self.correct_strings = {
            "PPOPP",  # used by DBLP
            "Proceedings of the 23rd {ACM} {SIGPLAN} Symposium on Principles and Practice of Parallel Programming, PPoPP 2018, Vienna, Austria, February 24-28, 2018",
            "Proceedings of the {ACM/SIGPLAN} {PPEALS} 1988, Parallel Programming: Experience with Applications, Languages and Systems, New Haven, Connecticut, USA, July 19-21, 1988",
            "Proceedings of the Second {ACM} {SIGPLAN} Symposium on Princiles {\&} Practice of Parallel Programming (PPOPP), Seattle, Washington, USA, March 14-16, 1990",
            "Proceedings of the 23rd ACM SIGPLAN Symposium on Principles and Practice of Parallel Programming",
        }

        self.wrong_strings = {
            "11th Workshop on General Purpose Processing using GPUs, GPGPU@PPoPP 2018, February 25, 2018, Vosendorf (Vienna), Austria",
            "Proceedings of the 4th Workshop on Programming Models for SIMD/Vector Processing, WPMVP@PPoPP 2018, Vienna, Austria, February 24, 2018",
            "Proceedings of the 9th International Workshop on Programming Models and Applications for Multicores and Manycores, PMAM@PPoPP 2018, February 25, 2018, Vienna, Austria",
        }



from tests.BaseRunner import BaseRunner


class TestCCPE(BaseRunner):

    def setUp(self):
        self.expected_venue = "CCPE"

        self.correct_strings = {
            "CCPE",  # used by DBLP
            "Concurrency - Practice and Experience",
            "Concurrency: practice and experience",
            "Concurrency and Computation: Practice and Experience",
            "Concurr. Comput. Pract. Exp.",
            "Concurrency and computation: practice and experience",
        }

        self.wrong_strings = {
        }



from tests.BaseRunner import BaseRunner


class TestPSI(BaseRunner):

    def setUp(self):
        self.expected_venue = "PSI"

        self.correct_strings = {
            "Perspectives of System Informatics - 9th International Ershov Informatics Conference, {PSI} 2014, St. Petersburg, Russia, June 24-27, 2014. Revised Selected Papers",
            "International Sympoisum on Theoretical Programming, Novosibirsk, Russia, August 7-11, 1972, Proceedings",
            "International Symposium on Theoretical Programming",  # Google Scholar
            "International Andrei Ershov Memorial Conference on Perspectives of System Informatics", # Google Scholar
            "Ershov Memorial Conference", # DBLP
        }

        self.wrong_strings = {
        }



from tests.BaseRunner import BaseRunner


class TestSOSP(BaseRunner):

    def setUp(self):
        self.expected_venue = "SOSP"

        self.correct_strings = {
            "SOSP",  # used by DBLP
            "Proceedings of the Second Symposium on Operating Systems Principles, {SOSP} 1969, Princeton, NJ, USA, October 20-22, 1969",
            "Proceedings of the second symposium on Operating systems principles",
            }

        self.wrong_strings = {
            "Proceedings of the 6th Workshop on Programming Languages and Operating Systems, PLOS@SOSP 2011, Cascais, Portugal, October 23, 2011",

            }



from tests.BaseRunner import BaseRunner


class TestP2P(BaseRunner):

    def setUp(self):
        self.expected_venue = "P2P"

        self.correct_strings = {
            "P2P",
            "1st International Conference on Peer-to-Peer Computing {(P2P} 2001), 27-29 August 2001, Link{\"{o}}ping, Sweden",
            "2015 {IEEE} International Conference on Peer-to-Peer Computing, {P2P} 2015, Boston, MA, USA, September 21-25, 2015",
            "Peer-to-Peer Computing (P2P), 2011 IEEE International Conference on",
            "{IEEE} Tenth International Conference on Peer-to-Peer Computing, {P2P} 2010, Delft, The Netherlands, 25-27 August 2010",
            "Peer-to-Peer Computing",  # DBLP
        }

        self.wrong_strings = {
        }



from tests.BaseRunner import BaseRunner


class TestIMC(BaseRunner):

    def setUp(self):
        self.expected_venue = "IMC"

        self.correct_strings = {
            r"IMC",  # used by DBLP
            r"Internet Measurement Workshop",  # used by DBLP
            r"Internet Measurement Conference",  # used by DBLP
            r"Proceedings of the 1st {ACM} {SIGCOMM} Internet Measurement Workshop, {IMW} 2001, San Francisco, California, USA, November 1-2, 2001",
            r"Proceedings of the 2nd {ACM} {SIGCOMM} Internet Measurement Workshop, {IMW} 2002, Marseille, France, November 6-8, 2002",
            r"Proceedings of the 1st ACM SIGCOMM Workshop on Internet Measurement",
            r"Proceedings of the 2nd ACM SIGCOMM Workshop on Internet measurment",  # Notice the typo? It's in Google Scholar like that :)
            r"Proceedings of the 3rd {ACM} {SIGCOMM} Internet Measurement Conference, {IMC} 2003, Miami Beach, FL, USA, October 27-29, 2003",
            r"Proceedings of the 3rd ACM SIGCOMM conference on Internet measurement",
            r"Proceedings of the 5th Internet Measurement Conference, {IMC} 2005, Berkeley, California, USA, October 19-21, 2005",
        }

        self.wrong_strings = {

        }



from tests.BaseRunner import BaseRunner


class TestWoWMoM(BaseRunner):

    def setUp(self):
        self.expected_venue = "WOWMOM"

        self.correct_strings = {
            "WoWMoM",
            "WOWMOM",
            "Proceedings of First {ACM} International Workshop on Wireless Mobile Multimedia, {WOWMOM} '98, Dallas, TX, USA, October 30, 1998",
            "Proceedings of the 1st ACM international workshop on Wireless mobile multimedia",
            "2005 International Conference on a World of Wireless, Mobile and Multimedia Networks {(WOWMOM} 2005), 13-16 June 2005, Taormina, Italy, Proceedings",
            "World of Wireless Mobile and Multimedia Networks, 2005. WoWMoM 2005. Sixth IEEE International Symposium on a",
            "19th {IEEE} International Symposium on \"A World of Wireless, Mobile and Multimedia Networks\", WoWMoM 2018, Chania, Greece, June 12-15, 2018",
        }

        self.wrong_strings = {
        }



from tests.BaseRunner import BaseRunner


class TestWORKS(BaseRunner):

    def setUp(self):
        self.expected_venue = "WORKS"

        self.correct_strings = {
            "SC-WORKS",
            "Proceedings of the 11th Workshop on Workflows in Support of Large-Scale Science co-located with The International Conference for High Performance Computing, Networking, Storage and Analysis {(SC} 2016), Salt Lake City, Utah, USA, November 14, 2016.",
            "Proceedings of the 4th Workshop on Workflows in Support of Large-Scale Science, {WORKS} 2009, November 16, 2009, Portland, Oregon, {USA}",
            "Workflows in support of large-scale science",  # DBLP
            "Proceedings of the 2nd workshop on Workflows in support of large-scale science",  # Google Scholar
            "2020 IEEE/ACM Workflows in Support of Large-Scale Science (WORKS)",
        }

        self.wrong_strings = {
        }



from tests.BaseRunner import BaseRunner


class TestUCC(BaseRunner):

    def setUp(self):
        self.expected_venue = "UCC"

        self.correct_strings = {
            "UCC",  # used by DBLP
            "{IEEE} 4th International Conference on Utility and Cloud Computing, {UCC} 2011, Melbourne, Australia, December 5-8, 2011"
            "Utility and Cloud Computing (UCC), 2011 Fourth IEEE International Conference on",
            "Proceedings of the 7th {IEEE/ACM} International Conference on Utility and Cloud Computing, {UCC} 2014, London, United Kingdom, December 8-11, 2014",
            "2018 IEEE/ACM 11th International Conference on Utility and Cloud Computing (UCC)",
            "Proceedings of the 9th International Conference on Utility and Cloud Computing",
        }

        self.wrong_strings = {
            "2018 {IEEE/ACM} International Conference on Utility and Cloud Computing Companion, {UCC} Companion 2018, Zurich, Switzerland, December 17-20, 2018",
            "Companion Proceedings of the 10th International Conference on Utility and Cloud Computing, {UCC} 2017, Austin, TX, USA, December 5-8, 2017",
        }



from tests.BaseRunner import BaseRunner


class TestPOPL(BaseRunner):

    def setUp(self):
        self.expected_venue = "POPL"

        self.correct_strings = {
            "POPL",  # used by DBLP
            "Conference Record of the {ACM} Symposium on Principles of Programming Languages, Boston, Massachusetts, USA, October 1973",
            "Proceedings of the 44th {ACM} {SIGPLAN} Symposium on Principles of Programming Languages, {POPL} 2017, Paris, France, January 18-20, 2017",
            "Proceedings of the 1st annual ACM SIGACT-SIGPLAN symposium on Principles of programming languages", # Google Scholar
        }

        self.wrong_strings = {
            "Proceedings of the {POPL} 2005 Workshop on Issues in the Theory of Security, {WITS} 2005, Long Beach, California, USA, January 10-11, 2005",
        }



from tests.BaseRunner import BaseRunner


class TestSIGMOD(BaseRunner):

    def setUp(self):
        self.expected_venue = "SIGMOD"

        self.correct_strings = {
            "SIGMOD",  # used by DBLP
            "SIGMOD Conference",
            "Proceedings of the 1975 {ACM} {SIGMOD} International Conference on Management of Data, San Jose, California, USA, May 14-16, 1975.",
            "Proceedings of the 1975 ACM SIGMOD international conference on Management of data",
            "SIGMOD'84, Proceedings of Annual Meeting, Boston, Massachusetts, USA, June 18-21, 1984",
            "Proceedings of the Association for Computing Machinery Special Interest Group on Management of Data 1987 Annual Conference, San Francisco, CA, USA, May 27-29, 1987",
            "Proceedings of the {ACM} {SIGMOD} International Conference on Management of Data, {SIGMOD} 2011, Athens, Greece, June 12-16, 2011",
            "Proceedings of the 2018 International Conference on Management of Data",
        }

        self.wrong_strings = {
            "Proceedings of the Workshop on Data Bases for Interactive Design, Canada, September 15-16, 1975.",
            "The Papers of the Fifth Workshop on Computer Architecture for Non-Numeric Processing, Pacific Grove, CA, USA, March 11-14, 1980",
            "Proceedings of the First International Workshop on Performance and Evaluation of Data Management Systems, ExpDB 2006, in cooperation with {ACM} SIGMOD, June 30, 2006, Chicago, Illinois, {USA}",
        }



import unittest

from venue_mapper.venue_mapper import VenueMapper


class BaseRunner(unittest.TestCase):
    expected_venue = ""
    correct_strings = {}
    wrong_strings = {}

    def runTest(self):
        venue_mapper = VenueMapper()
        for string in self.correct_strings:
            self.assertEqual(self.expected_venue, venue_mapper.get_abbreviation(string), "{0} failed.".format(string))

        for string in self.wrong_strings:
            self.assertNotEqual(self.expected_venue, venue_mapper.get_abbreviation(string),
                                "Didn't expect {0} for string {1}".format(venue_mapper.get_abbreviation(string), string))



from tests.BaseRunner import BaseRunner


class TestSPW(BaseRunner):

    def setUp(self):
        self.expected_venue = "SPW"

        self.correct_strings = {
            "SPW",
            "Security Protocols Workshop",  # DBLP
            "Security Protocols, International Workshop, Cambridge, United Kingdom, April 10-12, 1996, Proceedings",
            "International Workshop on Security Protocols",
            "Security Protocols {XXVI} - 26th International Workshop, Cambridge, UK, March 19-21, 2018, Revised Selected Papers",
            "Cambridge International Workshop on Security Protocols",
        }

        self.wrong_strings = {
        }



from tests.BaseRunner import BaseRunner


class TestJSSPP(BaseRunner):

    def setUp(self):
        self.expected_venue = "JSSPP"

        self.correct_strings = {
            "JSSPP",  # used by DBLP
            "Job Scheduling Strategies for Parallel Processing, IPPS'95 Workshop, Santa Barbara, CA, USA, April 25, 1995, Proceedings",
            "Workshop on Job Scheduling Strategies for Parallel Processing",
            "Job Scheduling Strategies for Parallel Processing - 19th and 20th International Workshops, {JSSPP} 2015, Hyderabad, India, May 26, 2015 and {JSSPP} 2016, Chicago, IL, USA, May 27, 2016, Revised Selected Papers",
        }

        self.wrong_strings = {
        }



from tests.BaseRunner import BaseRunner


class TestTC(BaseRunner):

    def setUp(self):
        self.expected_venue = "TC"

        self.correct_strings = {
            "TC",
            "{IEEE} Trans. Computers",
            "IEEE Transactions on Computers",
        }

        self.wrong_strings = {

        }



from tests.BaseRunner import BaseRunner


class TestTJS(BaseRunner):

    def setUp(self):
        self.expected_venue = "TJS"

        self.correct_strings = {
            "TJS",
            "The Journal of Supercomputing",
        }

        self.wrong_strings = {
            "Proceedings of the {ACM/IEEE} Conference on Supercomputing, {SC} 1999, November 13-19, 1999, Portland, Oregon, {USA}",
        }



import orjson
import ast
import datetime
import time
from venue_mapper.venue_mapper import VenueMapper


class PerformanceTest(object):

    def iterload_file_lines(self, file):
        for line in file.readlines():
            try:
                json_object = orjson.loads(line)
                yield json_object
            except Exception as e:
                try:
                    json_object = ast.literal_eval(line)
                    yield json_object
                except Exception as e2:
                    print("Could not parse line. Errors: {0} and: {1}".format(e, e2))
                    continue

    def test(self):
        venue_mapper = VenueMapper()
        start = time.time()
        import yappi
        yappi.set_clock_type("cpu")
        yappi.start()
        with open("test-files/s2-corpus-057", "r", encoding="ISO-8859-1") as json_file:
            # The json files contain stacked json objects, which is bad practice. It should be wrapped in a JSON array.
            # Libraries will throw errors if you attempt to load the file, so now we lazy load each object.
            publication_iterator = self.iterload_file_lines(json_file)
            for publication in publication_iterator:
                if publication is None:  # Corrupt JSON line possibly. Skip it.
                    continue

                if "venue" not in publication:  # While parsing we sometimes get KeyError: 'venue'...
                    continue

                # Try to match the publication to a venue we are interested in.
                # Wrap in str() as it sometimes is an int (???)
                venue_string = str(publication['venue'])
                if len(venue_string) == 0:
                    continue
                venue = venue_mapper.get_abbreviation(venue_string)
        yappi.stop()
        yappi.get_func_stats().save("venue_map_trace_{}".format(datetime.datetime.now().strftime("%Y-%m-%d %H:%M:%S")),
                                    type='callgrind')
        print(time.time() - start)


if __name__ == '__main__':
    performance_test = PerformanceTest()
    performance_test.test()
    # Old: 444.something
    # New: 99.76612067222595



from tests.BaseRunner import BaseRunner


class TestJIDPS(BaseRunner):

    def setUp(self):
        self.expected_venue = "JIDPS"

        self.correct_strings = {
            "JIDPS",  # Not observed in the wild, just to be safe.
            "J. Integrated Design {\&} Process Science",  # DBLP
            "Transactions of the {SDPS}",
            "Journal of Integrated Design and Process Science",  # Google Scholar
        }

        self.wrong_strings = {
        }



from tests.BaseRunner import BaseRunner


class TestISC(BaseRunner):

    def setUp(self):
        self.expected_venue = "ISC"

        self.correct_strings = {
            "ISC",  # used by DBLP
            "Supercomputer'89: Anwendungen, Architekturen, Trends, Seminar, Mannheim, 8.-10. Juni 1989, Proceedings",
            "Supercomputing - 28th International Supercomputing Conference, {ISC} 2013, Leipzig, Germany, June 16-20, 2013. Proceedings}",
            "International Supercomputing Conference",
            "Supercomputer'89",
            "High Performance Computing - 33rd International Conference, {ISC} High Performance 2018, Frankfurt, Germany, June 24-28, 2018, Proceedings",
        }

        self.wrong_strings = {
            "High Performance Computing - {ISC} High Performance 2017 International Workshops, DRBSD, ExaComm, HCPM, HPC-IODC, IWOPH, IXPUG, P{\^{}}3MA, VHPC, Visualization at Scale, WOPSSS, Frankfurt, Germany, June 18-22, 2017, Revised Selected Papers",
        }



from tests.BaseRunner import BaseRunner


class TestSPIRE(BaseRunner):

    def setUp(self):
        self.expected_venue = "SPIRE"

        self.correct_strings = {
            "SPIRE",  # used by DBLP
            "International symposium on string processing and information retrieval",
            "international symposium on string processing and information retrieval",
            "String Processing and Information Retrieval: {A} South American Symposium, {SPIRE} 1998, Santa Cruz de la Sierra Bolivia, September 9-11, 1998",
            "Proceedings. String Processing and Information Retrieval: A South American Symposium (Cat. No. 98EX207)",
            "Sixth International Symposium on String Processing and Information Retrieval and Fifth International Workshop on Groupware, {SPIRE/CRIWG} 1999, Cancun, Mexico, September 21-24, 1999",
            "6th International Symposium on String Processing and Information Retrieval. 5th International Workshop on Groupware (Cat. No. PR00268)",
        }

        self.wrong_strings = {
        }



from tests.BaseRunner import BaseRunner


class TestICPP(BaseRunner):

    def setUp(self):
        self.expected_venue = "ICPP"

        self.correct_strings = {
            "ICPP",  # used by DBLP
            "ICPP (1)",  # DBLP
            "International Conference on Parallel Processing, ICPP'82, August 24-27, 1982, Bellaire, Michigan, {USA}",
            "Proceedings of the International Conference on Parallel Processing, {ICPP} '88, The Pennsylvania State University, University Park, PA, USA, August 1988. Volume 2: Software.",
            "Proceedings of the 47th International Conference on Parallel Processing",
            "Proceedings of the 1994 International Conference on Parallel Processing, North Carolina State University, NC, USA, August 15-19, 1994. Volume {I:} Architecture.",
        }

        self.wrong_strings = {
            "32nd International Conference on Parallel Processing Workshops {(ICPP} 2003 Workshops), 6-9 October 2003, Kaohsiung, Taiwan",
            "The 47th International Conference on Parallel Processing, {ICPP} 2018, Workshop Proceedings, Eugene, OR, USA, August 13-16, 2018",
            "Proceedings of the 47th International Conference on Parallel Processing Companion",
        }



from tests.BaseRunner import BaseRunner


class TestSIGMETRICS(BaseRunner):

    def setUp(self):
        self.expected_venue = "SIGMETRICS"

        self.correct_strings = {
            "SIGMETRICS",  # used by DBLP
            "SIGMETRICS (Abstracts)",  # used by DBLP
            "Proceedings of the Joint International Conference on Measurements and Modeling of Computer Systems, {SIGMETRICS} 1976, March 29-31, 1976, Cambridge, MA, {USA}",
            "Proceedings of the 1976 ACM SIGMETRICS conference on Computer performance modeling measurement and evaluation",
            "Abstracts of the 2018 {ACM} International Conference on Measurement and Modeling of Computer Systems, {SIGMETRICS} 2018, Irvine, CA, USA, June 18-22, 2018",
            "Proceedings of the 12th ACM SIGMETRICS/PERFORMANCE joint international conference on Measurement and Modeling of Computer Systems",
        }

        self.wrong_strings = {
            "Proceedings of the 13th Workshop on Economics of Networks, Systems and Computation, NetEcon@SIGMETRICS 2018, Irvine, CA, USA, June 18, 2018",
        }



from tests.BaseRunner import BaseRunner


class TestMOBILESoft(BaseRunner):

    def setUp(self):
        self.expected_venue = "MOBILESoft"

        self.correct_strings = {
            "MOBILESoft",  # used by DBLP
            "Proceedings of the 1st International Conference on Mobile Software Engineering and Systems, MOBILESoft 2014, Hyderabad, India, June 2-3, 2014}",
            "Proceedings of the 1st International Conference on Mobile Software Engineering and Systems",
            "Proceedings of the 5th International Conference on Mobile Software Engineering and Systems, MOBILESoft@ICSE 2018, Gothenburg, Sweden, May 27 - 28, 2018",
        }

        self.wrong_strings = {
            }



from tests.BaseRunner import BaseRunner


class TestEDBT(BaseRunner):

    def setUp(self):
        self.expected_venue = "EDBT"

        self.correct_strings = {
            "EDBT",  # used by DBLP
            "Advances in Database Technology - EDBT'88, Proceedings of the International Conference on Extending Database Technology, Venice, Italy, March 14-18, 1988",
            "International Conference on Extending Database Technology",
            "Proceedings of the Workshops of the {EDBT/ICDT} 2018 Joint Conference {(EDBT/ICDT} 2018), Vienna, Austria, March 26, 2018.",
            "Workshops of the EDBT/ICDT 2017 Joint Conference (EDBT/ICDT 2017)",
        }

        self.wrong_strings = {
        }



from tests.BaseRunner import BaseRunner


class TestDSN(BaseRunner):

    def setUp(self):
        self.expected_venue = "SASO"

        self.correct_strings = {
            r"SASO",  # used by DBLP
            r"13th {IEEE} International Conference on Self-Adaptive and Self-Organizing Systems, {SASO} 2019, Umea, Sweden, June 16-20, 2019",
            r"2019 IEEE 13th International Conference on Self-Adaptive and Self-Organizing Systems (SASO)",
            r"Proceedings of the First International Conference on Self-Adaptive and Self-Organizing Systems, {SASO} 2007, Boston, MA, USA, July 9-11, 2007",
        }

        self.wrong_strings = {
            r"SASO Workshops",
            r"{IEEE} 4th International Workshops on Foundations and Applications of Self* Systems, FAS*W@SASO/ICCAC 2019, Umea, Sweden, June 16-20, 2019",
            r"2019 IEEE 4th International Workshops on Foundations and Applications of Self* Systems (FAS* W)",
        }



from tests.BaseRunner import BaseRunner


class TestIC(BaseRunner):

    def setUp(self):
        self.expected_venue = "IC"

        self.correct_strings = {
            "IC",  # used by DBLP
            "IEEE Internet Computing",
            "{IEEE} Internet Computing",
        }

        self.wrong_strings = {
        }



from tests.BaseRunner import BaseRunner


class TestFGCS(BaseRunner):

    def setUp(self):
        self.expected_venue = "FGCS"

        self.correct_strings = {
            "FGCS",  # used by DBLP
            "Future Generation Comp. Syst.",
            "Future Generation Computer Systems",
            "Future Gener. Comput. Syst.",
        }

        self.wrong_strings = {
        }



from tests.BaseRunner import BaseRunner


class TestGRID(BaseRunner):

    def setUp(self):
        self.expected_venue = "GRID"

        self.correct_strings = {
            "GRID",  # used by DBLP
            "Grid Computing - {GRID} 2000, First {IEEE/ACM} International Workshop, Bangalore, India, December 17, 2000, Proceedings",
            "International Workshop on Grid Computing",
            "Proceedings of the 2010 11th {IEEE/ACM} International Conference on Grid Computing, Brussels, Belgium, October 25-29, 2010",
            "Grid Computing (GRID), 2010 11th IEEE/ACM International Conference on",
            "Proceedings of the 7th IEEE/ACM International Conference on Grid Computing",
        }

        self.wrong_strings = {
        }



from tests.BaseRunner import BaseRunner


class TestSERVICES(BaseRunner):

    def setUp(self):
        self.expected_venue = "SERVICES"

        self.correct_strings = {
            "SERVICES",  # used by DBLP
            "SERVICES I",  # DBLP
            "SERVICES II",
            "2008 {IEEE} Congress on Services, Part I, {SERVICES} {I} 2008, Honolulu, Hawaii, USA, July 6-11, 2008",
            "Services-Part I, 2008. IEEE Congress on",
            "2018 {IEEE} World Congress on Services, {SERVICES} 2018, San Francisco, CA, USA, July 2-7, 2018",
            "2018 IEEE World Congress on Services (SERVICES)",
            "IEEE SCW",  # DBLP at it again
        }

        self.wrong_strings = {
            "Services with a fake name to test the regex lookahead",
            }



from tests.BaseRunner import BaseRunner


class TestIPDPS(BaseRunner):

    def setUp(self):
        self.expected_venue = "IPDPS"

        self.correct_strings = {
            "IPDPS",  # used by DBLP
            "2018 {IEEE} International Parallel and Distributed Processing Symposium, {IPDPS} 2018, Vancouver, BC, Canada, May 21-25, 2018",
            "18th International Parallel and Distributed Processing Symposium {(IPDPS} 2004), {CD-ROM} / Abstracts Proceedings, 26-30 April 2004, Santa Fe, New Mexico, {USA}",
            "Parallel and Distributed Processing Symposium, 2004. Proceedings. 18th International",
        }

        self.wrong_strings = {
            "The Fifth International Parallel Processing Symposium, Proceedings, Anaheim, California, USA, April 30 - May 2, 1991.",
            "11th International Parallel Processing Symposium {(IPPS} '97), 1-5 April 1997, Geneva, Switzerland, Proceedings",
            "Job Scheduling Strategies for Parallel Processing, IPPS/SPDP'99 Workshop, JSSPP'99, San Juan, Puerto Rico, April 16, 1999, Proceedings",
        }



from tests.BaseRunner import BaseRunner


class TestFAST(BaseRunner):

    def setUp(self):
        self.expected_venue = "FAST"

        self.correct_strings = {
            r"FAST",  # used by DBLP
            r"Proceedings of the {FAST} '02 Conference on File and Storage Technologies, January 28-30, 2002, Monterey, California, {USA}",
            r"17th {USENIX} Conference on File and Storage Technologies, {FAST} 2019, Boston, MA, February 25-28, 2019",
            r"17th $\{$USENIX$\}$ Conference on File and Storage Technologies ($\{$FAST$\}$ 19)",
        }

        self.wrong_strings = {
            r"2007 Linux Storage {\&} Filesystem Workshop, {LSF} 2007, San Jose, CA, USA, February 12-13, 2007",
        }



from tests.BaseRunner import BaseRunner


class TestTrueNegatives(BaseRunner):

    def setUp(self):
        self.expected_venue = None

        self.correct_strings = {
            "",
            " ",
            "fake conference",
            "?",
            "none",
            "null",
        }

        self.wrong_strings = {
            }



from tests.BaseRunner import BaseRunner


class TestOSDI(BaseRunner):

    def setUp(self):
        self.expected_venue = "OSDI"

        self.correct_strings = {
            "OSDI",  # used by DBLP
            "Proceedings of the First {USENIX} Symposium on Operating Systems Design and Implementation (OSDI), Monterey, California, USA, November 14-17, 1994",
            "9th {USENIX} Symposium on Operating Systems Design and Implementation, {OSDI} 2010, October 4-6, 2010, Vancouver, BC, Canada, Proceedings",
            "13th $\{$USENIX$\}$ Symposium on Operating Systems Design and Implementation ($\{$OSDI$\}$ 18)",
            "Proceedings of the 1st USENIX conference on Operating Systems Design and Implementation",
        }

        self.wrong_strings = {
            "2010 Workshop on the Economics of Networks, Systems, and Computation, NetEcon@OSDI 2010, Vancouver, BC, Canada, October 3, 2010",
            "4th Workshop on Interactions of NVM/Flash with Operating Systems and Workloads, INFLOW@OSDI 2016, Savannah, GA, USA, November 1, 2016.",
        }



from tests.BaseRunner import BaseRunner


class TestJPDC(BaseRunner):

    def setUp(self):
        self.expected_venue = "JPDC"

        self.correct_strings = {
            "Journal of Parallel and Distributed Computing",  # Google Scholar
            "J. Parallel Distrib. Comput.",  # DBLP
            "J. Parallel Distributed Comput.",
        }

        self.wrong_strings = {
        }



from tests.BaseRunner import BaseRunner


class TestCCGrid(BaseRunner):

    def setUp(self):
        self.expected_venue = "CCGrid"

        self.correct_strings = {
            r"CCGrid",
            r"CCGRID",
            r"18th IEEE/ACM International Symposium on Cluster, Cloud and Grid Computing, CCGRID 2018, Washington, DC, USA, May 1-4, 2018.",
            r"15th {IEEE/ACM} International Symposium on Cluster, Cloud and Grid Computing, CCGrid 2015, Shenzhen, China, May 4-7, 2015",
            r"First IEEE International Symposium on Cluster Computing and the Grid (CCGrid 2001), May 15-18, 2001, Brisbane, Australia.",
            r"Proceedings of the 2011 11th IEEE/ACM International Symposium on Cluster, Cloud and Grid Computing",
            r"Cluster Computing and the Grid, 2005. CCGrid 2005. IEEE International Symposium on",
            r"10th {IEEE/ACM} International Conference on Cluster, Cloud and Grid Computing, CCGrid 2010, 17-20 May 2010, Melbourne, Victoria, Australia",
            r"Cluster, Cloud and Grid Computing (CCGrid), 2013 13th IEEE/ACM International Symposium on",
        }

        self.wrong_strings = {
            r"The First International Workshop on Advances in High-Performance Algorithms Middleware and Applications (AHPAMA 2018)",
            r"3rd IEEE/ACM International Workshop on Distributed Big Data Management (DBDM 2018)",
        }



from tests.BaseRunner import BaseRunner


class TestICWS(BaseRunner):

    def setUp(self):
        self.expected_venue = "ICWS"

        self.correct_strings = {
            "ICWS",  # used by DBLP
            "ICWS Computer Society",
            "ICWS-Europe",
            "Proceedings of the {IEEE} International Conference on Web Services (ICWS'04), June 6-9, 2004, San Diego, California, {USA}",
            "Web Services, 2004. Proceedings. IEEE International Conference on",
        }

        self.wrong_strings = {
            "2011 7th International Conference on Next Generation Web Services Practices",
        }



from tests.BaseRunner import BaseRunner


class TestSC(BaseRunner):

    def setUp(self):
        self.expected_venue = "SC"

        self.correct_strings = {
            "SC",  # used by DBLP
            "Proceedings of the {ACM/IEEE} {SC2005} Conference on High Performance Networking and Computing, November 12-18, 2005, Seattle, WA, USA, CD-Rom",
            "Proceedings of the International Conference for High Performance Computing, Networking, Storage and Analysis, {SC} 2015, Austin, TX, USA, November 15-20, 2015",
            "Proceedings Supercomputing '88, Orlando, FL, USA, November 12-17, 1988",
            "Proceedings of the {ACM/IEEE} Conference on Supercomputing, {SC} 1999, November 13-19, 1999, Portland, Oregon, {USA}",
            "SC State of the Practice Reports",  # DBLP
            "International Conference on Supercomputing",
            "Conference on High Performance Computing Networking, Storage and Analysis, {SC} 2011, Seattle, WA, USA, November 12-18, 2011",
            "Proceedings of the Conference on High Performance Computing Networking, Storage and Analysis",
        }

        self.wrong_strings = {
            "{IEEE/ACM} 8th Workshop on Fault Tolerance for {HPC} at eXtreme Scale, FTXS@SC 2018, Dallas, TX, USA, November 16, 2018"
            "WHPCF'11, Proceedings of the Fourth Workshop on High Performance Computational Finance, co-located with SC11, Seattle, WA, USA, November 13, 2011",
        }



from tests.BaseRunner import BaseRunner


class TestNSDI(BaseRunner):

    def setUp(self):
        self.expected_venue = "NSDI"

        self.correct_strings = {
            "NSDI",  # used by DBLP
            "1st Symposium on Networked Systems Design and Implementation {(NSDI} 2004), March 29-31, 2004, San Francisco, California, USA, Proceedings",
            "15th {USENIX} Symposium on Networked Systems Design and Implementation, {NSDI} 2018, Renton, WA, USA, April 9-11, 2018",
            "USENIX Symposium on Networked Systems Design and Implementation",  # Google Scholar
        }

        self.wrong_strings = {
        }



from tests.BaseRunner import BaseRunner


class TestICDCS(BaseRunner):

    def setUp(self):
        self.expected_venue = "ICDCS"

        self.correct_strings = {
            r"ICDCS",  # used by DBLP
            r"38th {IEEE} International Conference on Distributed Computing Systems, {ICDCS} 2018, Vienna, Austria, July 2-6, 2018",
            r"Proceedings of the 2nd International Conference on Distributed Computing Systems, Paris, France, 1981",
            r"29th {IEEE} International Conference on Distributed Computing Systems {(ICDCS} 2009), 22-26 June 2009, Montreal, Qu{\'{e}}bec, Canada",
            r"Distributed Computing Systems, 2009. ICDCS'09. 29th IEEE International Conference on",
            r"2019 IEEE 39th International Conference on Distributed Computing Systems (ICDCS)",
        }

        self.wrong_strings = {
            r"37th {IEEE} International Conference on Distributed Computing Systems Workshops, {ICDCS} Workshops 2017, Atlanta, GA, USA, June 5-8, 2017",
        }



from tests.BaseRunner import BaseRunner


class TestEuroSys(BaseRunner):

    def setUp(self):
        self.expected_venue = "EuroSys"

        self.correct_strings = {
            "EuroSys",  # used by DBLP
            "Proceedings of the 2006 EuroSys Conference, Leuven, Belgium, April 18-21, 2006",
            "ACM SIGOPS Operating Systems Review",
            "European Conference on Computer Systems, Proceedings of the 5th European conference on Computer systems, EuroSys 2010, Paris, France, April 13-16, 2010",
            "Proceedings of the Tenth European Conference on Computer Systems",
        }

        self.wrong_strings = {
            "Proceedings of the 1st workshop on Middleware-Application Interaction, {MAI} 2007, in conjunction with Euro-Sys 2007, Lisbon, Portugal, March 20, 2007",
            "Proceedings of the Fourth International Workshop on Cloud Data and Platforms, CloudDP@EuroSys 2014, Amsterdam, The Netherlands, April 13, 2014",
        }



from tests.BaseRunner import BaseRunner


class TestEuroPar(BaseRunner):

    def setUp(self):
        self.expected_venue = "Euro-Par"

        self.correct_strings = {
            "Euro-Par",  # used by DBLP
            "Euro-Par (1)",
            "Euro-Par '95 Parallel Processing, First International Euro-Par Conference, Stockholm, Sweden, August 29-31, 1995, Proceedings",
            "European Conference on Parallel Processing",
            "Euro-Par 2018: Parallel Processing - 24th International Conference on Parallel and Distributed Computing, Turin, Italy, August 27-31, 2018, Proceedings"
        }

        self.wrong_strings = {
            "Euro-Par 2012: Parallel Processing Workshops - BDMC, CGWS, HeteroPar, HiBB, OMHI, Paraphrase, PROPER, Resilience, UCHPC, VHPC, Rhodes Islands, Greece, August 27-31, 2012. Revised Selected Papers",
            "Euro-Par 2016: Parallel Processing Workshops - Euro-Par 2016 International Workshops, Grenoble, France, August 24-26, 2016, Revised Selected Papers",
            "Seventh International Conference on Parallel and Distributed Computing, Applications and Technologies {(PDCAT} 2006), 4-7 December 2006, Taipei, Taiwan",
        }



from tests.BaseRunner import BaseRunner


class TestDSN(BaseRunner):

    def setUp(self):
        self.expected_venue = "DSN"

        self.correct_strings = {
            r"DSN",  # used by DBLP
            r"2000 International Conference on Dependable Systems and Networks {(DSN} 2000) (formerly {FTCS-30} and DCCA-8), 25-28 June 2000, New York, NY, {USA}",
            r"Proceeding International Conference on Dependable Systems and Networks. DSN 2000",
            r"49th Annual {IEEE/IFIP} International Conference on Dependable Systems and Networks, {DSN} (Industry Track) 2019, Portland, OR, USA, June 24-27, 2019",
            r"2006 International Conference on Dependable Systems and Networks {(DSN} 2006), 25-28 June 2006, Philadelphia, Pennsylvania, USA, Proceedings",
        }

        self.wrong_strings = {
            r"DSN Workshops",
            r"49th Annual {IEEE/IFIP} International Conference on Dependable Systems and Networks Workshops, {DSN} Workshops 2019, Portland, OR, USA, June 24-27, 2019",
            r""
        }



from tests.BaseRunner import BaseRunner


class TestEScience(BaseRunner):

    def setUp(self):
        self.expected_venue = "e-Science"

        self.correct_strings = {
            "e-Science and Grid Computing, 2005. First International Conference on",
            "First International Conference on e-Science and Grid Technologies (e-Science 2005), 5-8 December 2005, Melbourne, Australia",
            "14th {IEEE} International Conference on e-Science, e-Science 2018, Amsterdam, The Netherlands, October 29 - November 1, 2018",
            "First International Conference on e-Science and Grid Computing (e-Science'05)",
            "Third International Conference on e-Science and Grid Computing, e-Science 2007, 10-13 December 2007, Bangalore, India",
            "2015 IEEE 11th International Conference on e-Science",
        }

        self.wrong_strings = {
            "10th {IEEE} International Conference on e-Science, eScience Workshops 2014, Sao Paulo, Brazil, October 20-24, 2014"
        }



from tests.BaseRunner import BaseRunner


class TestPC(BaseRunner):

    def setUp(self):
        self.expected_venue = "PC"

        self.correct_strings = {
            "PC",  # Used by DBLP
            "Parallel Computing",
        }

        self.wrong_strings = {
        }



from tests.BaseRunner import BaseRunner


class TestISWC(BaseRunner):

    def setUp(self):
        self.expected_venue = "ISWC"

        self.correct_strings = {
            "ISWC",  # used by DBLP
            "First International Symposium on Wearable Computers {(ISWC} 1997), Cambridge, Massachusetts, USA, 13-14 October 1997, Proceedings.",
            "Wearable Computers, 1997. Digest of Papers., First International Symposium on",
            "Proceedings of the 2015 {ACM} International Joint Conference on Pervasive and Ubiquitous Computing and Proceedings of the 2015 {ACM} International Symposium on Wearable Computers, UbiComp/ISWC Adjunct 2015, Osaka, Japan, September 7-11, 2015",
            "Adjunct Proceedings of the 2017 {ACM} International Joint Conference on Pervasive and Ubiquitous Computing and Proceedings of the 2017 {ACM} International Symposium on Wearable Computers, UbiComp/ISWC 2017, Maui, HI, USA, September 11-15, 2017",
            "Proceedings of the 2017 ACM International Joint Conference on Pervasive and Ubiquitous Computing and Proceedings of the 2017 ACM International Symposium on Wearable Computers",
        }

        self.wrong_strings = {
        }



from tests.BaseRunner import BaseRunner


class TestSSDBM(BaseRunner):

    def setUp(self):
        self.expected_venue = "SSDBM"

        self.correct_strings = {
            "SSDBM",  # used by DBLP
            "Proceedings of the First {LBL} Workshop on Statistical Database Management, Melno Park, California, USA, December 2-4, 1981",
            "Proceedings of the Second International Workshop on Statistical Database Management, Los Altos, California, USA, September 27-29, 1983",
            "Proceedings of the Third International Workshop on Statistical and Scientific Database Management, July 22-24, 1986, Grand Duchy of Luxembourg, Luxembourg",
            "Proceedings of the 15th International Conference on Scientific and Statistical Database Management {(SSDBM} 2003), 9-11 July 2003, Cambridge, MA, {USA}",
        }

        self.wrong_strings = {
        }



from tests.BaseRunner import BaseRunner


class TestPODS(BaseRunner):

    def setUp(self):
        self.expected_venue = "PODS"

        self.correct_strings = {
            "Proceedings of the {ACM} Symposium on Principles of Database Systems, March 29-31, 1982, Los Angeles, California, {USA}",
            "Proceedings of the 31st {ACM} {SIGMOD-SIGACT-SIGART} Symposium on Principles of Database Systems, {PODS} 2012, Scottsdale, AZ, USA, May 20-24, 2012",
            "Proceedings of the 31st ACM SIGMOD-SIGACT-SIGAI symposium on Principles of Database Systems",
        }

        self.wrong_strings = {

        }



from tests.BaseRunner import BaseRunner


class TestISPA(BaseRunner):

    def setUp(self):
        self.expected_venue = "ISPA"

        self.correct_strings = {
            "Parallel and Distributed Processing and Applications, International Symposium, {ISPA} 2003, Aizu, Japan, July 2-4, 2003, Proceedings",
            "12th {IEEE} International Conference on Trust, Security and Privacy in Computing and Communications, TrustCom 2013 / 11th {IEEE} International Symposium on Parallel and Distributed Processing with Applications, {ISPA-13} / 12th {IEEE} International Conference on Ubiquitous Computing and Communications, IUCC-2013, Melbourne, Australia, July 16-18, 2013",
            "2017 {IEEE} International Symposium on Parallel and Distributed Processing with Applications and 2017 {IEEE} International Conference on Ubiquitous Computing and Communications (ISPA/IUCC), Guangzhou, China, December 12-15, 2017",
            "Ubiquitous Computing and Communications (ISPA/IUCC), 2017 IEEE International Symposium on Parallel and Distributed Processing with Applications and 2017 IEEE International Conference on",
        }

        self.wrong_strings = {
            "2011 IEEE Ninth International Symposium on Parallel and Distributed Processing with Applications Workshops"
        }



from tests.BaseRunner import BaseRunner


class TestFedCSIS(BaseRunner):

    def setUp(self):
        self.expected_venue = "FedCSIS"

        self.correct_strings = {
            "FedCSIS",  # used by DBLP
            "Federated Conference on Computer Science and Information Systems - FedCSIS 2011, Szczecin, Poland, 18-21 September 2011, Proceedings",
            "Proceedings of the 2018 Federated Conference on Computer Science and Information Systems, FedCSIS 2018, Pozna{\'{n}}, Poland, September 9-12, 2018.",
            "2011 Federated Conference on Computer Science and Information Systems (FedCSIS)",
        }

        self.wrong_strings = {
            "AI-Science@HPDC", "ScienceCloud@HPDC", "ROSS@HPDC",
            "Proceedings of the 5th IEEE workshop on Challenges of large applications in distributed environments, CLADE@HPDC 2007, Monterey, California, USA, June 25, 2007",
            "Proceedings of the 2nd Workshop on the Use of P2P, GRID and Agents for the Development of Content Networks, UPGRADE-CN'07, jointly held with the 16th International Symposium on High-Performance Distributed Computing (HPDC-16 2007), 26 June 2007, Monterey, California, USA."
            "Proceedings of the 2007 workshop on Grid monitoring, GMW@HPDC 2007, Monterey, California, USA, June 25, 2007",
            "Proceedings of the 3rd Workshop on the Use of P2P, GRID and Agents for the Development of Content Networks, UPGRADE-CN'08, jointly held with the 17th International Symposium on High-Performance Distributed Computing (HPDC-17 2008), 23 June 2008, Boston, MA, USA",
            "Proceedings of the 7th International Workshop on Runtime and Operating Systems for Supercomputers, ROSS@HPDC 2017, Washingon, DC, DC, USA, June 27 - 27, 2017.",
            "Proceedings of the 1st International Workshop on Autonomous Infrastructure for Science, AI-Science@HPDC 2018, Tempe, AZ, USA, June 11, 2018.",
        }



from tests.BaseRunner import BaseRunner


class TestTOPLAS(BaseRunner):

    def setUp(self):
        self.expected_venue = "TOPLAS"

        self.correct_strings = {
            "TOPLAS",  # used by DBLP
            "{ACM} Trans. Program. Lang. Syst.",  # DBLP
            "ACM Transactions on Programming Languages and Systems (TOPLAS)",
            }

        self.wrong_strings = {
            }



from tests.BaseRunner import BaseRunner


class TestCloudCom(BaseRunner):

    def setUp(self):
        self.expected_venue = "CloudCom"

        self.correct_strings = {
            "CloudCom",  # used by DBLP
            "CloudCom (1)",  # DBLP
            "Cloud Computing, First International Conference, CloudCom 2009, Beijing, China, December 1-4, 2009. Proceedings",
            "Cloud Computing, Second International Conference, CloudCom 2010, November 30 - December 3, 2010, Indianapolis, Indiana, USA, Proceedings",
            "{IEEE} 3rd International Conference on Cloud Computing Technology and Science, CloudCom 2011, Athens, Greece, November 29 - December 1, 2011",
            "IEEE} 5th International Conference on Cloud Computing Technology and Science, CloudCom 2013, Bristol, United Kingdom, December 2-5, 2013, Volume 2",
            "2018 {IEEE} International Conference on Cloud Computing Technology and Science, CloudCom 2018, Nicosia, Cyprus, December 10-13, 2018",
            "2018 IEEE International Conference on Cloud Computing Technology and Science (CloudCom)",

        }

        self.wrong_strings = {
        }



from tests.BaseRunner import BaseRunner


class TestINFOCOM(BaseRunner):

    def setUp(self):
        self.expected_venue = "INFOCOM"

        self.correct_strings = {
            "INFOCOM",  # used by DBLP
            "Proceedings {IEEE} {INFOCOM} '91, The Conference on Computer Communications, Tenth Annual Joint Conference of the {IEEE} Computer and Communications Societies, Networking in the 90s, Bal Harbour, Florida, USA, April 7-11, 1991",
            "[Proceedings] IEEE INFOCOM'92: The Conference on Computer Communications",  # Google Scholar
            "IEEE INFOCOM 2019-IEEE Conference on Computer Communications",  # Used by Google Scholar
        }

        self.wrong_strings = {
            "INFOCOM Workshop",
            "{IEEE} {INFOCOM} 2018 - {IEEE} Conference on Computer Communications Workshops, {INFOCOM} Workshops 2018, Honolulu, HI, USA, April 15-19, 2018",
            "IEEE INFOCOM 2018-IEEE Conference on Computer Communications Workshops (INFOCOM WKSHPS)",
            }



from tests.BaseRunner import BaseRunner


class TestNOSSDAV(BaseRunner):

    def setUp(self):
        self.expected_venue = "NOSSDAV"

        self.correct_strings = {
            "NOSSDAV",  # used by DBLP
            "Network and Operating System Support for Digital Audio and Video, Second International Workshop, Heidelberg, Germany, November 18-19, 1991, Proceedings",
            "International Workshop on Network and Operating System Support for Digital Audio and Video",
            }

        self.wrong_strings = {
            }



from tests.BaseRunner import BaseRunner


class TestISPDC(BaseRunner):

    def setUp(self):
        self.expected_venue = "ISPDC"

        self.correct_strings = {
            "ISPDC",  # used by DBLP
            "16th International Symposium on Parallel and Distributed Computing, {ISPDC} 2017, Innsbruck, Austria, July 3-6, 2017",
            "2nd International Symposium on Parallel and Distributed Computing {(ISPDC} 2003), 13-14 October 2003, Ljubljana, Slovenia",
            "2018 17th International Symposium on Parallel and Distributed Computing (ISPDC)",  # Google Scholar
        }

        self.wrong_strings = {
            }



from tests.BaseRunner import BaseRunner


class TestCVPR(BaseRunner):

    def setUp(self):
        self.expected_venue = "CVPR"

        self.correct_strings = {
            "CVPR",
            "CVPR (1)",
            "CVPR (2)",
            "{IEEE} Computer Society Conference on Computer Vision and Pattern Recognition, {CVPR} 1988, 5-9 June, 1988, Ann Arbor, Michigan, {USA.}",
            "2018 {IEEE} Conference on Computer Vision and Pattern Recognition, {CVPR} 2018, Salt Lake City, UT, USA, June 18-22, 2018",
            "Proceedings of the IEEE Conference on Computer Vision and Pattern Recognition (CVPR)",
        }

        self.wrong_strings = {
            "{IEEE} Conference on Computer Vision and Pattern Recognition Workshops, {CVPR} Workshops 2004, Washington, DC, USA, June 27 - July 2, 2004",
            "CVPR Workshop on Disguised Faces in the Wild",
        }



import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="Venue Mapper",
    version="1.0.1",
    author="Laurens Versluis",
    author_email="l.f.d.versluis@vu.nl",
    description="Maps BibTex venue/journal/booktitle strings to their acronyms.",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/atlarge-research/venue_mappings",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.5',
)



from tests.BaseRunner import BaseRunner


class TestCLOUD(BaseRunner):

    def setUp(self):
        self.expected_venue = "CLOUD"

        self.correct_strings = {
            "CLOUD",  # used by DBLP
            "IEEE CLOUD",  # DBLP
            "{IEEE} International Conference on Cloud Computing, {CLOUD} 2009, Bangalore, India, 21-25 September, 2009",
            "2009 IEEE International Conference on Cloud Computing",
            "2018 IEEE 11th International Conference on Cloud Computing (CLOUD)",
        }

        self.wrong_strings = {
        }



from tests.BaseRunner import BaseRunner


class TestAISTATS(BaseRunner):

    def setUp(self):
        self.expected_venue = "AISTATS"

        self.correct_strings = {
            "AISTATS",  # used by DBLP
            "Learning from Data - Fifth International Workshop on Artificial Intelligence and Statistics, {AISTATS} 1995, Key West, Florida, USA, January, 1995. Proceedings.",
            "Learning from Data",  # Google Scholar
            "International Conference on Artificial Intelligence and Statistics",  # Google Scholar
        }
        self.wrong_strings = {
            }



from tests.BaseRunner import BaseRunner


class TestIBMRD(BaseRunner):

    def setUp(self):
        self.expected_venue = "IBMRD"

        self.correct_strings = {
            "{IBM} Journal of Research and Development",
            "IBM Journal of Research and Development", # Google Scholar
        }

        self.wrong_strings = {
            }



import re
from enum import Enum


class MatchType(Enum):
    EXACT = 1
    STARTS_WITH = 2
    ENDS_WITH = 3
    CONTAINS = 4
    REGEX = 5


class VenueMapper(object):
    venues = {
        "AISTATS": {
            (r"AISTATS", MatchType.EXACT),
            (r"{AISTATS}", MatchType.CONTAINS),
            (r"Learning from Data", MatchType.EXACT),
            (r"International Conference on Artificial Intelligence and Statistics", MatchType.EXACT),
            (r"International Workshop on Artificial Intelligence and Statistics,", MatchType.CONTAINS),
        },
        "SIGCSE": {
            (r"SIGSCSE", MatchType.EXACT),  # DBLP
            (r"{SIGCSE}", MatchType.CONTAINS),
            (r"ACM Technical Symposium on Computer Science Education", MatchType.CONTAINS),
        },
        "CloudComp": {
            (r"CloudComp", MatchType.EXACT),  # DBLP
            (r"International Conference, CloudComp", MatchType.CONTAINS),
            (r"International Conference on Cloud Computing", MatchType.EXACT),
        },
        "FedCSIS": {
            (r"FedCSIS", MatchType.EXACT),
            (r"Federated Conference on Computer Science and Information Systems", MatchType.CONTAINS),
        },
        "PSI": {
            (r"{PSI}", MatchType.CONTAINS),
            (r"Perspectives of System Informatics", MatchType.STARTS_WITH),
            (r"International Sympoisum on Theoretical Programming", MatchType.STARTS_WITH),
            (r"International Symposium on Theoretical Programming", MatchType.STARTS_WITH),
            (r"Ershov Memorial Conference", MatchType.CONTAINS),
        },
        "ISPA": {
            (r"ISPA", MatchType.EXACT),
            (r"{ISPA}", MatchType.CONTAINS),
            (
                r"^(?=.*International Symposium on Parallel and Distributed Processing with Applications)(?!.*\bWorkshops\b).*$",
                MatchType.REGEX),
        },
        "IBMRD": {
            (r"IBMRD", MatchType.EXACT),
            (r"{IBM} Journal of Research and Development", MatchType.CONTAINS),
            (r"IBM Journal of Research and Development", MatchType.CONTAINS),
        },
        "ICDCS": {
            (r"ICDCS", MatchType.EXACT),  # used by DBLP
            (r"International Conference on Distributed Computing Systems,", MatchType.CONTAINS),
            (r"International Conference on Distributed Computing Systems {(ICDCS}", MatchType.CONTAINS),
            (r"International Conference on Distributed Computing Systems (ICDCS)", MatchType.CONTAINS),
            (r"Distributed Computing Systems,", MatchType.STARTS_WITH),
        },
        "OSDI": {
            (r"OSDI", MatchType.EXACT),  # used by DBLP
            (r"Symposium on Operating Systems Design and Implementation", MatchType.CONTAINS),
            (r"conference on Operating Systems Design and Implementation", MatchType.CONTAINS),
        },
        "ICFEC": {
            (r"ICFEC", MatchType.EXACT),
            (r"{ICFEC}", MatchType.CONTAINS),
            (r"(ICFEC)", MatchType.CONTAINS),
        },
        "CVPR": {
            (r"^CVPR( \(\d\))?$", MatchType.REGEX),
            (r"(CVPR)", MatchType.CONTAINS),
            (r"\{CVPR\} (?!Workshops)", MatchType.REGEX),
        },
        "JPDC": {
            (r"J. Parallel Distrib. Comput.", MatchType.EXACT),  # Used by DBLP
            (r"Journal of Parallel and Distributed Computing", MatchType.EXACT),
            (r"J. Parallel Distributed Comput.", MatchType.EXACT),
        },
        # "IFIP": {
        #     "IFIP"
        # },
        "POPL": {
            (r"POPL", MatchType.EXACT),  # DBLP
            (r"(S|s)ymposium on Principles of (P|p)rogramming (L|l)anguages", MatchType.REGEX),
        },
        "SOSP": {
            (r"SOSP", MatchType.EXACT),  # DBLP
            (r"{SOSP}", MatchType.CONTAINS),
            (r"Symposium on Operating Systems Principles", MatchType.CONTAINS),
            (r"symposium on Operating systems principles", MatchType.CONTAINS),  # Google Scholar, lower case
        },
        "P2P": {
            (r"P2P", MatchType.EXACT),
            (r"{(P2P}", MatchType.CONTAINS),
            (r"{P2P}", MatchType.CONTAINS),
            (r"(P2P)", MatchType.CONTAINS),
            (r"Peer-to-Peer Computing", MatchType.EXACT),
        },
        "ICCSE": {
            (r"ICCSE", MatchType.EXACT),
            (r"{ICCSE}", MatchType.CONTAINS),
            (r"(ICCSE)", MatchType.CONTAINS),
            (r"Internation Conference on Computer Science and Education", MatchType.ENDS_WITH),
        },
        "TPDS": {
            (r"Trans. Parallel Distrib. Syst.", MatchType.ENDS_WITH),
            (r"(t|T)ransactions on (p|P)arallel and (d|D)istributed (s|S)ystems", MatchType.REGEX),
        },
        "SERVICES": {
            (r"^SERVICES( (I|II))?$", MatchType.REGEX),
            (r"{SERVICES}", MatchType.CONTAINS),
            (r"(SERVICES)", MatchType.CONTAINS),
            (r"IEEE SCW", MatchType.EXACT),
            (r"^(?=.*\bServices(-Part)?\b)(?=.*\bCongress on\b).*$", MatchType.REGEX),
        },
        "TOPLAS": {
            (r"TOPLAS", MatchType.EXACT),
            (r"Trans. Program. Lang. Syst.", MatchType.ENDS_WITH),
            (r"(TOPLAS)", MatchType.CONTAINS),
        },
        "WORKS": {
            (r"SC-WORKS", MatchType.EXACT),
            (r"{WORKS}", MatchType.CONTAINS),
            (r"(WORKS)", MatchType.CONTAINS),
            (r"(w|W)orkshop on Workflows in (s|S)upport of (l|L)arge-(s|S)cale (s|S)cience", MatchType.REGEX),
            (r"Workflows in support of large-scale science", MatchType.EXACT),
        },
        "NDSS": {
            (r"NDSS", MatchType.EXACT),
            (r"(NDSS)", MatchType.CONTAINS),
            (r"\{(\(S\))?NDSS\}", MatchType.REGEX),
            (r"^(?=.*\bNetwork and Distributed System Security\b)(?=.*\bSymposium\b).*$", MatchType.REGEX),
        },
        "MOBILESoft": {
            (r"MOBILESoft", MatchType.EXACT),
            (r"International Conference on Mobile Software Engineering and Systems(,|$)", MatchType.REGEX),
        },
        "CCGrid": {
            (r"CCGrid", MatchType.EXACT),  # used by DBLP
            (r"CCGRID", MatchType.EXACT),  # also used by DBLP
            (r"(CCGrid)", MatchType.CONTAINS),  # also used by DBLP
            (r"Cluster Computing and the Grid,", MatchType.STARTS_WITH),  # also used by DBLP
            (r"International Symposium on Cluster, Cloud and Grid Computing,", MatchType.CONTAINS),
            (r"International Conference on Cluster, Cloud and Grid Computing,", MatchType.CONTAINS),
            (r"International Symposium on Cluster Computing and the Grid", MatchType.CONTAINS),
            (r"International Symposium on Cluster, Cloud and Grid Computing", MatchType.CONTAINS),
        },
        "NOSSDAV": {
            (r"NOSSDAV", MatchType.EXACT),
            (r"Network and Operating System Support for Digital Audio and Video,", MatchType.CONTAINS),
            (r"Network and Operating System Support for Digital Audio and Video", MatchType.ENDS_WITH),
        },
        "ISWC": {
            (r"ISWC", MatchType.EXACT),
            (r"{ISWC}", MatchType.CONTAINS),
            (r"{(ISWC}", MatchType.CONTAINS),
            (r"^(?=.*\bWearable Computers\b)(?=.*\bInternational Symposium\b).*$", MatchType.REGEX),
        },
        "IPDPS": {
            (r"IPDPS", MatchType.EXACT),  # used by DBLP
            (r"{IPDPS}", MatchType.CONTAINS),
            (r"Parallel and Distributed Processing Symposium,", MatchType.CONTAINS),
            (r"International Parallel and Distributed Processing Symposium {(IPDPS}", MatchType.CONTAINS),
            # Tricky one, as workshops use the same booktitle.
        },
        "WOWMOM": {
            (r"WoWMoM", MatchType.EXACT),  # DBLP
            (r"WOWMOM", MatchType.EXACT),
            (r"(i|I)nternational workshop on Wireless mobile multimedia(,|$)", MatchType.REGEX),
            (r"{WOWMOM}", MatchType.CONTAINS),
            (r"{(WOWMOM}", MatchType.CONTAINS),
            (r"^(?=.*\bWorld of Wireless,? Mobile and Multimedia Networks\b)(?=.*\bSymposium\b).*$", MatchType.REGEX),
        },
        "SPW": {
            (r"SPW", MatchType.EXACT),
            (r"Security Protocols Workshop", MatchType.EXACT),
            (r"^(?=.*\bInternational Workshop\b( on|,))(?=.*\bSecurity Protocols\b).*$", MatchType.REGEX),
        },
        "JSSPP": {
            (r"JSSPP", MatchType.EXACT),
            (r"{JSSPP}", MatchType.CONTAINS),
            (r"Job Scheduling Strategies for Parallel Processing(,|$)", MatchType.REGEX),
        },
        "UCC": {
            (r"UCC", MatchType.EXACT),
            (r"(UCC)", MatchType.CONTAINS),
            (r"^(?=.*International Conference on Utility and Cloud Computing)(?!.*\bCompanion\b).*$", MatchType.REGEX),
        },
        "ISCID": {
            (r"^ISCID( \(\d\))?$", MatchType.REGEX),
            (r"^(?=.*\bInternational Symposium on)(?=.*\bComputational Intelligence and Design\b).*$", MatchType.REGEX),
        },
        "SIGMETRICS": {
            (r"SIGMETRICS", MatchType.EXACT),
            (r"{SIGMETRICS}", MatchType.CONTAINS),
            (r"SIGMETRICS (Abstracts)", MatchType.CONTAINS),
            (r"SIGMETRICS conference on Computer performance modeling measurement and evaluation", MatchType.ENDS_WITH),
            (r"ACM SIGMETRICS/PERFORMANCE joint international conference on Measurement and Modeling of Computer Systems", MatchType.CONTAINS),
        },
        "EDBT": {
            (r"EDBT", MatchType.EXACT),
            (r"\(EDBT/ICDT \d{4}\)", MatchType.REGEX),
            (r"\{\(EDBT/ICDT\} \d{4}\)", MatchType.REGEX),
            (r"International Conference on Extending Database Technology,", MatchType.CONTAINS),
            (r"International Conference on Extending Database Technology", MatchType.ENDS_WITH),
        },
        "ICWS": {
            (r"ICWS", MatchType.EXACT),  # DBLP
            (r"ICWS-Europe", MatchType.EXACT),  # DBLP
            (r"ICWS Computer Society", MatchType.EXACT),
            (r"\(ICWS'\d{2}\)", MatchType.REGEX),
            (r"^(?=.*\bInternational Conference on)(?=.*\bWeb Services\b)(?!.*\bPractices\b).*$", MatchType.REGEX),
        },
        "CLOUD": {
            (r"^(IEEE )?CLOUD$", MatchType.REGEX),  # DBLP
            (r"{CLOUD}", MatchType.CONTAINS),
            (r"(CLOUD)", MatchType.CONTAINS),
            (r"International Conference on Cloud Computing", MatchType.ENDS_WITH),

        },
        "FiCloud": {
            (r"FiCloud", MatchType.EXACT),
            (r"(FiCloud)", MatchType.CONTAINS),
            (r"International Conference on Future Internet of Things and Cloud,", MatchType.CONTAINS),
        },
        "GCC": {
            (r"GCC", MatchType.EXACT),
            (r"^GCC \(\d\)$", MatchType.REGEX),
            (r"\{GCC\} (?!.*\bWorkshops\b)", MatchType.REGEX),
            (r"International Conference on Grid and Cooperative Computing(,|$)", MatchType.REGEX),
        },
        "SIGCOMM": {
            (r"SIGCOMM", MatchType.EXACT),
            (r"\{SIGCOMM\} (?!.*\bworkshop\b)", MatchType.REGEX),
            (r"ACM SIGCOMM Computer Communication Review", MatchType.EXACT),
            (r"ACM Special Interest Group on Data Communication", MatchType.ENDS_WITH),
        },
        "SIGMOD": {
            (r"SIGMOD Conference", MatchType.EXACT),
            (r"SIGMOD", MatchType.EXACT),
            (r"{SIGMOD}", MatchType.CONTAINS),
            (r"(i|I)nternational (c|C)onference on Management of (d|D)ata$", MatchType.REGEX),
            (r"SIGMOD'\d{2}", MatchType.REGEX),
            (r"Association for Computing Machinery Special Interest Group on Management of Data", MatchType.CONTAINS),
        },
        "SoCC": {
            (r"SoCC", MatchType.EXACT),
            (r"(s|S)ymposium on Cloud (c|C)omputing(, SoCC|$)", MatchType.REGEX),
        },
        "ICPE": {
            (r"ICPE", MatchType.EXACT),
            (r"{WOSP}", MatchType.CONTAINS),
            (r"^(?=.*\bICPE\b)(?!.*\bCompanion\b)(?!.*\bworkshop\b)(?!.*\bECCE\b).*$", MatchType.REGEX),
            (r"international workshop on Software and performance", MatchType.ENDS_WITH),
            (r"{WOSP/SIPEW}", MatchType.CONTAINS),
        },
        "SSDBM": {
            (r"SSDBM", MatchType.EXACT),  # DBLP
            (r"\{\(SSDBM\} \d{4}\)", MatchType.REGEX),
            (r"{LBL} Workshop on Statistical Database Management,", MatchType.CONTAINS),
            (r"International Workshop on Statistical and Scientific Database Management,", MatchType.CONTAINS),
            (r"International Workshop on Statistical Database Management,", MatchType.CONTAINS),
        },
        # "IDEAS": {
        #     "IDEAS",
        #     "International Database Engineering {&} Applications Symposium"
        # },
        "GRADES@SIGMOD-PODS": {
            (r"GRADES@SIGMOD/PODS", MatchType.CONTAINS),
            (r"International Workshop on Graph Data-management Experiences {\&} Systems", MatchType.CONTAINS),
            (r"International Workshop on Graph Data-management Experiences {&} Systems", MatchType.CONTAINS),
        },
        "HPDC": {
            (r"HPDC", MatchType.EXACT),
            (r"{HPDC}", MatchType.CONTAINS),
            (r"{(HPDC}", MatchType.CONTAINS),
            (r"{(HPDC-", MatchType.CONTAINS),
            (r"International Symposium on High Performance Distributed Computing,", MatchType.CONTAINS),
            (r"High-Performance Distributed Computing,", MatchType.STARTS_WITH),  # Notice the carrot.
            (r"International Symposium on High Performance Parallel and Distributed Computing,", MatchType.CONTAINS),
            (r"International Symposium on High-Performance Parallel and Distributed Computing,", MatchType.CONTAINS),
        },
        "AI-Science": {  # HPDC workshop
            (r"AI-Science@HPDC", MatchType.CONTAINS),
            (r"International Workshop on Autonomous Infrastructure for Science,", MatchType.CONTAINS),
        },
        "ScienceCloud": {  # HPDC workshop
            (r"ScienceCloud@HPDC", MatchType.CONTAINS),
            (r"Workshop on Scientific Cloud Computing,", MatchType.CONTAINS),
        },
        "ROSS": {  # HPDC workshop
            (r"ROSS@HPDC", MatchType.CONTAINS),
            (r"International Workshop on Runtime and Operating Systems for Supercomputers,", MatchType.CONTAINS),
        },
        "GRID": {
            (r"GRID", MatchType.EXACT),
            (r"{GRID}", MatchType.CONTAINS),
            (r"(GRID)", MatchType.CONTAINS),
            (r"International Workshop on Grid Computing", MatchType.EXACT),
            (r"International Conference on Grid Computing", MatchType.CONTAINS),
        },
        # "BroadNets": {
        #     "BroadNets",
        #     "International Conference on Broadnets Networks"
        # },
        # "WOOT": {
        #     "WOOT",
        #     "USENIX workshop on Offensive Technologies"
        # },
        # "CACM": {
        #     "CACM",
        #     "Communications of the ACM"
        # },
        "IC": {
            (r"IC", MatchType.EXACT),
            (r"IEEE Internet Computing", MatchType.EXACT),
            (r"{IEEE} Internet Computing", MatchType.EXACT),
        },
        "ICAC": {
            (r"ICAC", MatchType.EXACT),
            (r"International Conference on Autonomic Computing,", MatchType.CONTAINS),
            (r"{ICAC}", MatchType.CONTAINS),
            (r"\{\(ICAC} \d+\)", MatchType.REGEX),
        },
        "Euro-Par": {
            (r"^Euro-(p|P)ar( \(\d\))?$", MatchType.REGEX),
            (r"European Conference on Parallel Processing", MatchType.EXACT),
            (r"International Euro-Par Conference", MatchType.CONTAINS),
            (r"^(?=.*\bEuro-Par\b)(?=.*\bInternational Conference on Parallel and Distributed Computing\b).*$",
             MatchType.REGEX),
        },
        "NSDI": {
            (r"NSDI", MatchType.EXACT),  # used by DBLP
            (r"Symposium on Networked Systems Design and Implementation", MatchType.CONTAINS),
        },
        # "WWW": {
        #     "WWW",
        #     "International Conference on World Wide Web Companion"
        # },
        "FGCS": {
            (r"FGCS", MatchType.EXACT),
            (r"Future Generation Computer Systems", MatchType.EXACT),
            (r"Future Gener. Comput. Syst.", MatchType.EXACT),
            (r"Future Generation Comp. Syst.", MatchType.CONTAINS),
        },
        "EuroSys": {
            (r"EuroSys", MatchType.EXACT),  # DBLP
            (r"ACM SIGOPS Operating Systems Review", MatchType.EXACT),
            (r"European (c|C)onference on Computer (S|s)ystems", MatchType.REGEX),
            (r"EuroSys Conference,", MatchType.CONTAINS),
        },
        "ISPDC": {
            (r"ISPDC", MatchType.EXACT),
            (r"{ISPDC}", MatchType.CONTAINS),
            (r"{(ISPDC}", MatchType.CONTAINS),
            (r"(ISPDC)", MatchType.CONTAINS),
        },
        # "MobiCom": {
        #     "MobiCom",
        #     "International Conference on Mobile Computing and Networking"
        # },
        "IC2E": {
            (r"IC2E", MatchType.EXACT),
            (r"\{IC2E\} (?!.*\bWorkshops\b).*", MatchType.REGEX),
            (r"(IC2E)", MatchType.CONTAINS),
        },
        "CLUSTER": {
            (r"CLUSTER", MatchType.EXACT),  # used by DBLP
            (r"{CLUSTER}", MatchType.CONTAINS),
            (r"(CLUSTER)", MatchType.CONTAINS),
            (r"Cluster Computing, \d{4}\.", MatchType.REGEX),  # Google scholar
            (r"International Conference on Cluster Computing,", MatchType.CONTAINS),
            (r"International Conference on Cluster Computing {(CLUSTER}", MatchType.CONTAINS),
        },
        # "AINA": {
        #     "AINA",
        #     "Advanced Information Networking and Applications"
        # },
        "SC": {
            (r"SC", MatchType.EXACT),  # used by DBLP
            (r"International Conference on Supercomputing", MatchType.EXACT),  # used by DBLP
            (r"{SC2005}", MatchType.CONTAINS),  # Funny mislabeling from the past.
            (r"{SC}", MatchType.CONTAINS),  # Funny mislabeling from the past.
            (r"Proceedings Supercomputing ", MatchType.STARTS_WITH),
            (r"SC State of the Practice Reports", MatchType.EXACT),  # DBLP
            (r"{ACM/IEEE} Conference on Supercomputing,", MatchType.CONTAINS),
            (r"^(?=.*International Conference for High Performance Computing,)(?!.*\bWorkshop\b).*$", MatchType.REGEX),
            (r"^(?=.*Conference on High Performance Computing Networking, Storage and Analysis)(?!.*\bWorkshop\b).*$",
             MatchType.REGEX),
        },
        # "HPC": {
        #     r"High-Performance Computing in China:",
        # },
        # "MMVE": {
        #     "MMVE",
        #     "International Workshop on Massively Multiusers Virtual Environment"
        # },
        # "GLOBECOM": {
        #     "GLOBECOM"
        # },
        "ATC": {
            (r"{ATC}", MatchType.CONTAINS),
            (r"Proc. of ATC", MatchType.EXACT),
            (r"{USENIX} Summer Conference", MatchType.CONTAINS),
            (r"Usenix Winter \d{4} Technical Conference,", MatchType.REGEX),
            (r"Technical Conference on {UNIX} and Advanced Computing Systems,", MatchType.CONTAINS),
            (r"{FREENIX} Track:", MatchType.CONTAINS),
            (r"USENIX Annual Technical Conference", MatchType.EXACT),  # used by DBLP
            (r"{USENIX} Annual Technical Conference,", MatchType.CONTAINS),
            (r"$ATC$", MatchType.CONTAINS),
        },
        "CCPE": {
            (r"CCPE", MatchType.EXACT),  # not in DBPL, but just in case.
            (r"Concurr. Comput. Pract. Exp.", MatchType.EXACT),  # not in DBPL, but just in case.
            (r"Concurrency - Practice and Experience", MatchType.EXACT),
            (r"Concurrency: practice and experience", MatchType.EXACT),
            (r"^Concurrency and (C|c)omputation: (P|p)ractice and (E|e)xperience$", MatchType.REGEX),
        },
        # "TOIT": {
        #     "TOIT",
        #     "Transactions on Internet Technology",
        # },
        # "TWEB": {
        #     "TWEB",
        #     "Transactions on the Web"
        # },
        # "PODC": {
        #     "PODC",
        #     "Symposium on Principles of Distributed Computing",
        #
        # },
        # "Middleware": {
        #     "Middleware Conference",
        #     "International Middleware Conference",
        #     "International Conference on Distributed Systems Platforms"
        #     "Middleware",
        # },
        "ISC": {
            (r"ISC", MatchType.EXACT),
            (r"\{ISC\} (?!.*\bWorkshops\b)", MatchType.REGEX),
            (r"International Supercomputing Conference", MatchType.EXACT),
            (r"Supercomputer", MatchType.CONTAINS),
        },
        # "LISA": {
        #     "LISA",
        #     "Large Installation System Administration Conference",
        #     "Conference on Systems Administration",
        # },
        "FAST": {
            (r"FAST", MatchType.EXACT),
            (r"{FAST}", MatchType.CONTAINS),
            (r"$\{$FAST$\}$", MatchType.CONTAINS),
        },
        "SYSTOR": {
            (r"SYSTOR", MatchType.EXACT),
            (r"The Israeli Experimental Systems Conference", MatchType.CONTAINS),
            (r"International Conference on Systems and Storage(,|$)", MatchType.REGEX),
        },
        "INFOCOM": {
            (r"INFOCOM", MatchType.EXACT),
            (r"\{INFOCOM\}(?!.*\bWorkshops?\b).*$", MatchType.REGEX),
            (r"IEEE INFOCOM(?!.*\bWorkshops?\b).*$", MatchType.REGEX),
        },
        "CloudCom": {
            (r"^CloudCom( \(\d\))?$", MatchType.REGEX),  # DBLP
            (r"(CloudCom)", MatchType.CONTAINS),
            (r", CloudCom \d{4},", MatchType.REGEX),
            (r"International Conference on Cloud Computing Technology and Science, CloudCom", MatchType.CONTAINS),
        },
        "ICPP": {
            (r"^ICPP( \(\d\))?$", MatchType.REGEX),
            (r"International Conference on Parallel Processing(,|$)(?!.*\bWorkshop\b).*", MatchType.REGEX),
            (r"\{ICPP\}(?!.*\bWorkshop\b).*$", MatchType.REGEX),
        },
        "HPCC": {
            (r"HPCC", MatchType.EXACT),  # DBLP
            (r"{HPCC}", MatchType.CONTAINS),
            (r"HPCC-ICESS", MatchType.EXACT),
            (r"HPCC/CSS/ICESS", MatchType.EXACT),
            (r"HPCC/SmartCity/DSS", MatchType.EXACT),
            (r"HPCC/EUC", MatchType.EXACT),
            (r"^(?=.*\bInternational Conference on\b)(?=.*\bHigh Performance Computing and Communications?\b).*$",
             MatchType.REGEX),
        },
        "IJHPCA": {
            (r"^IJHPCA( \(\d\))?$", MatchType.REGEX),
            (r"{IJHPCA}", MatchType.CONTAINS),
            (r"International Journal of High Performance Computing Applications", MatchType.ENDS_WITH),
        },
        "e-Science": {
            (r"e-Science", MatchType.EXACT),  # used by DBLP
            (r"e-Science and Grid Computing,", MatchType.STARTS_WITH),
            (r"^(?!.*Workshops).*International Conference on e-Science.*$", MatchType.REGEX),
        },
        # "CIS": {
        #     "Computational Intelligence and Security"
        # },
        # "MIPRO": {
        #     "MIPRO",
        #     "Information and Communication Technology, Electronics and Microelectronics"
        # },
        "TOMPECS": {
            (r"TOMPECS", MatchType.EXACT),  # used by DBLP
            (r"{TOMPECS}", MatchType.EXACT),
            (r"Transactions on Modeling and Performance Evaluation of Computing Systems", MatchType.CONTAINS),
        },
        # "JISA": {
        #     "JISA",
        #     "Journal of Internet Services and Applications"
        # },
        # "NetGames": {
        #     "NetGames",
        #     "Annual Workshop on Network and Systems Support for Games"
        # },
        "PPOPP": {
            (r"PPOPP", MatchType.EXACT),
            (r"{PPEALS}", MatchType.CONTAINS),
            (r"(PPOPP)", MatchType.CONTAINS),
            (r"\{?ACM\}? \{?SIGPLAN\}? Symposium on Principles and Practice of Parallel Programming", MatchType.REGEX),
        },
        "TJS": {
            (r"TJS", MatchType.EXACT),
            (r"The Journal of Supercomputing", MatchType.EXACT),
        },
        "PC": {
            (r"PC", MatchType.EXACT),
            (r"Parallel Computing", MatchType.EXACT),
        },
        "HiPC": {
            (r"HiPC", MatchType.EXACT),
            (r"(HiPC)", MatchType.CONTAINS),
            (r"HiPC'\d{2}", MatchType.REGEX),
            (r"International Conference on High Performance Computing,", MatchType.CONTAINS),
        },
        "TC": {
            (r"TC", MatchType.EXACT),
            (r"{IEEE} Trans. Computers", MatchType.EXACT),
            (r"IEEE Transactions on Computers", MatchType.EXACT),
        },
        "PODS": {
            (r"PODS", MatchType.EXACT),  # DBLP
            (r"(S|s)ymposium on Principles of Database Systems", MatchType.REGEX),
        },
        "HotCloud": {
            (r"HotCloud", MatchType.EXACT),
            (r"Workshop on Hot Topics in Cloud Computing,", MatchType.CONTAINS),

        },
        "SPIRE": {
            (r"SPIRE", MatchType.EXACT),
            (r"{SPIRE}", MatchType.CONTAINS),
            (r"(i|I)nternational (s|S)ymposium on (s|S)tring (p|P)rocessing and (i|I)nformation (r|R)etrieval",
             MatchType.REGEX),
            (r"String Processing and Information Retrieval:", MatchType.CONTAINS),
        },
        "JIDPS": {
            (r"JIDPS", MatchType.EXACT),
            (r"Journal of Integrated Design and Process Science", MatchType.EXACT),
            (r"Transactions of the {SDPS}", MatchType.CONTAINS),
            (r"J. Integrated Design {\&} Process Science", MatchType.EXACT),
        },
        "DSN": {
            (r"DSN", MatchType.EXACT),
            (r"International Conference on Dependable Systems and Networks(?!.*\bWorkshops\b).*", MatchType.REGEX),
        },
        "SASO": {
            (r"SASO", MatchType.EXACT),
            (r"International Conference on Self-Adaptive and Self-Organizing Systems", MatchType.CONTAINS),
        },
        "IMC": {
            (r"IMC", MatchType.EXACT),
            (r"Internet Measurement Workshop", MatchType.EXACT),
            (r"Internet Measurement Conference", MatchType.EXACT),
            (r"{IMW}", MatchType.CONTAINS),
            (r"{IMC}", MatchType.CONTAINS),
            (r"on Internet measurment", MatchType.ENDS_WITH),  # The typo is correct - this is in Google Scholar
            (r"on Internet (M|m)easurement$", MatchType.REGEX),
        },
    }

    def __init__(self):
        self.cache = dict()
        self.starts_with_dict = dict()
        self.ends_with_dict = dict()
        self.compiled_regexes = dict()
        self.contains_dict = dict()

        for venue_abbreviation, match_tuples in self.venues.items():
            regex_parts = []

            for match_line, matchtype in match_tuples:
                if matchtype == MatchType.REGEX:
                    regex_parts.append(match_line)

                elif matchtype == MatchType.EXACT:
                    self.cache[match_line] = venue_abbreviation

                elif matchtype == MatchType.STARTS_WITH:
                    if venue_abbreviation not in self.starts_with_dict:
                        self.starts_with_dict[venue_abbreviation] = []
                    self.starts_with_dict[venue_abbreviation].append(match_line)

                elif matchtype == MatchType.ENDS_WITH:
                    if venue_abbreviation not in self.ends_with_dict:
                        self.ends_with_dict[venue_abbreviation] = []
                    self.ends_with_dict[venue_abbreviation].append(match_line)

                elif matchtype == MatchType.CONTAINS:
                    if venue_abbreviation not in self.contains_dict:
                        self.contains_dict[venue_abbreviation] = []

                    self.contains_dict[venue_abbreviation].append(match_line)

            if len(regex_parts):
                # Concatenate regexes using OR groups to improve the speed. One giant regex evaluates faster than
                # multiple smaller ones.
                combined_regex = "({})".format("|".join(["({})".format(r) for r in regex_parts]))
                self.compiled_regexes[venue_abbreviation] = re.compile(combined_regex)

    def get_abbreviation(self, bibtex_string):
        if bibtex_string in self.cache:
            return self.cache[bibtex_string]

        for venue_abbreviation, strings in self.starts_with_dict.items():
            if any(str(bibtex_string).startswith(s) for s in strings):
                self.cache[bibtex_string] = venue_abbreviation
                return venue_abbreviation

        for venue_abbreviation, strings in self.ends_with_dict.items():
            if any(str(bibtex_string).endswith(s) for s in strings):
                self.cache[bibtex_string] = venue_abbreviation
                return venue_abbreviation

        for venue_abbreviation, contain_strings in self.contains_dict.items():
            if any(s in bibtex_string for s in contain_strings):
                self.cache[bibtex_string] = venue_abbreviation
                return venue_abbreviation

        for venue_abbreviation, regex in self.compiled_regexes.items():
            if regex.search(bibtex_string):
                self.cache[bibtex_string] = venue_abbreviation
                return venue_abbreviation

        return None



from tests.BaseRunner import BaseRunner


class TestTJS(BaseRunner):

    def setUp(self):
        self.expected_venue = "HotCloud"

        self.correct_strings = {
            "HotCloud",  # Google Scholar
            "Workshop on Hot Topics in Cloud Computing, HotCloud'09, San Diego, CA, USA, June 15, 2009",
            "8th {USENIX} Workshop on Hot Topics in Cloud Computing, HotCloud 2016, Denver, CO, USA, June 20-21, 2016.",
        }

        self.wrong_strings = {
        }



from tests.BaseRunner import BaseRunner


class TestFiCloud(BaseRunner):

    def setUp(self):
        self.expected_venue = "FiCloud"

        self.correct_strings = {
            "FiCloud",  # used by DBLP
            "5th {IEEE} International Conference on Future Internet of Things and Cloud, FiCloud 2017, Prague, Czech Republic, August 21-23, 2017",
            "Future Internet of Things and Cloud (FiCloud), 2017 IEEE 5th International Conference on",
            "2014 International Conference on Future Internet of Things and Cloud, FiCloud 2014, Barcelona, Spain, August 27-29, 2014",
        }

        self.wrong_strings = {
        }



from tests.BaseRunner import BaseRunner


class TestTOMPECS(BaseRunner):

    def setUp(self):
        self.expected_venue = "TOMPECS"

        self.correct_strings = {
            "TOMPECS",  # used by DBLP
            "{TOMPECS}",
            "ACM Transactions on Modeling and Performance Evaluation of Computing Systems (TOMPECS)",
        }

        self.wrong_strings = {
            }



from tests.BaseRunner import BaseRunner


class TestATC(BaseRunner):

    def setUp(self):
        self.expected_venue = "ATC"

        self.correct_strings = {
            r"USENIX Annual Technical Conference",  # used by DBLP
            r"Proceedings of the {USENIX} Summer Conference, Altanta, GA, USA, June 1986",
            r"Proceedings of the Usenix Winter 1993 Technical Conference, San Diego, California, USA, January 1993",
            r"Proceedings of the {USENIX} Annual Technical Conference, San Diego, California, USA, January 22-26, 1996",
            r"Proceedings of the {FREENIX} Track: 1999 {USENIX} Annual Technical Conference, June 6-11, 1999, Monterey, California, {USA}",
            r"2017 {USENIX} Annual Technical Conference, {USENIX} {ATC} 2017, Santa Clara, CA, USA, July 12-14, 2017.",
            r"Proc. of ATC",  # Used by Google Scholar
            r"2018 $\{$USENIX$\}$ Annual Technical Conference ($\{$USENIX$\}$$\{$ATC$\}$ 18)",
        }

        self.wrong_strings = {
        }



from tests.BaseRunner import BaseRunner


class TestIC2E(BaseRunner):

    def setUp(self):
        self.expected_venue = "IC2E"

        self.correct_strings = {
            "IC2E",  # used by DBLP
            "Cloud Engineering (IC2E), 2014 IEEE International Conference on",
            "2013 {IEEE} International Conference on Cloud Engineering, {IC2E} 2013, San Francisco, CA, USA, March 25-27, 2013}",
        }

        self.wrong_strings = {
            "2016 {IEEE} International Conference on Cloud Engineering Workshop, {IC2E} Workshops, Berlin, Germany, April 4-8, 2016",
        }



from tests.BaseRunner import BaseRunner


class TestICFEC(BaseRunner):

    def setUp(self):
        self.expected_venue = "ICFEC"

        self.correct_strings = {
            "ICFEC",  # DBLP
            "1st {IEEE} International Conference on Fog and Edge Computing, {ICFEC} 2017, Madrid, Spain, May 14-15, 2017",
            "Fog and Edge Computing (ICFEC), 2018 IEEE 2nd International Conference on", # Google Scholar
        }

        self.wrong_strings = {
        }
